@@ -4,7 +4,7 @@
 ###############################################################################
 
 getfirstphi <- function(x,dat,stimuli,V,tps,reps,hmmiterations,
-		lambda=NULL,B=NULL,Z=NULL,fanin=4,gam=NULL,it=NULL,K=NULL) {
+		lambda=NULL,B=NULL,Z=NULL,fanin=4,gam=NULL,it=NULL,K=NULL,priortype="none") {
 	cat("-")
 	if(is.null(x)) {
 		phireference <- matrix(0,nrow=nrow(dat),ncol=nrow(dat),dimnames=list(rownames(dat),rownames(dat)))
@@ -13,13 +13,13 @@ getfirstphi <- function(x,dat,stimuli,V,tps,reps,hmmiterations,
 		phireference <- x
 		phiasis <- TRUE
 	}			
-	# for all i>2 sample random start networks
+	# get a random network
 	ps <- samplephi(phireference,stimuli,V,tps,reps,dat,searchstatespace=TRUE,hmmiterations=hmmiterations,
-			phiasis=phiasis,lambda=lambda,B=B,Z=Z,fanin=fanin,gam=gam,it=it,K=K)
+			phiasis=phiasis,lambda=lambda,B=B,Z=Z,fanin=fanin,gam=gam,it=it,K=K,priortype=priortype)
 	model <- list(phi=ps$phi.n, L=ps$Lnew, aic=ps$aicnew, bic=ps$bicnew, posterior=ps$posterior,
 			dat=dat, theta=ps$theta, gamma=ps$gammax, gammaposs=ps$gammaposs,tps=tps,
-			stimuli=stimuli,reps=reps,hmmiterations=hmmiterations, TSA=NULL, Tt=NULL, lastmove=NULL,
-			coords=c(1,1), lambda=lambda, B=B, Z=Z, fanin=fanin, gam=gam, it=it, K=K)
+			stimuli=stimuli,reps=reps,hmmiterations=hmmiterations, lastmove=NULL,
+			coords=c(1,1), lambda=lambda, B=B, Z=Z, fanin=fanin, gam=gam, it=it, K=K, pr=ps$pr, priortype=priortype)
 	model
 }
 
