@@ -10,8 +10,7 @@ mcmc_move <- function(bestmodel, type) {
 	phiorig <- bestmodel$phi.orig
 	numposs <- 0
 	fanin <- bestmodel$fanin
-	#if(type=="add") {
-	if(type=="addinhibition" || type=="addactivation" || type=="add") {
+	if(type %in% c("addinhibition","addactivation","add")) {
 		phi <- bestmodel$phi
 		diag(phi) <- 1
 		phi[,unlist(stimuli)] <- matrix(1,nrow=nrow(phi),ncol=length(unlist(stimuli)))
@@ -29,6 +28,14 @@ mcmc_move <- function(bestmodel, type) {
 		## pr that exactly the edge added is deleted, this is for the proposal density
 		possback <- which(bestmodel$phi!=0) + 1 # all edges that are not 0 plus the one added
 		rm(phi)
+#		if(length(poss)>0) {
+#			## check if edges would point to a stimulus node
+#			cds <- sapply(poss, coord, mat=bestmodel$phi)
+#			if(any(cds[2,] %in% unique(unlist(stimuli)))) {
+#				print("Error: add edge would be drawn to a stimulus.")
+#				browser()
+#			}
+#		}
 	}
 	if(type=="delete") {
 		poss <- which(bestmodel$phi!=0)
@@ -48,28 +55,47 @@ mcmc_move <- function(bestmodel, type) {
 		poss <- which(bestmodel$phi!=0)
 		possback <- poss
 	}
-	if(type=="revert") {
+	if(type=="revert" | type=="revswitch") {
 		phi <- bestmodel$phi
+		## which of the nodes already have fanin incoming edges
 		fanin_omit <- which(colSums(detailed.to.simple.regulations(bestmodel$phi))>=fanin)
+		## set all outgoing edges of these nodes to 0, since they must not be reverted
 		for(i in fanin_omit) {
 			phi[i,] <- rep(0,ncol(phi))
 		}
+		## all edges that would go into a stimulus if reverting are not allowed to revert
+		phi[unique(unlist(stimuli)), ] <- 0
+		## exclude edges that are disconnected
+		#noreach <- which(apply(gammaposs, 1, function(x) all(x==0)))
+		#for(i in noreach) {
+		#	phi[i,] <- rep(1,ncol(phi))
+		#}
+		
+		## which edges are allowed to revert/revswitch
 		poss <- which(phi!=0)
 		for(p in poss) {
 			cs <- coord(p,bestmodel$phi)
-			if(bestmodel$phi[cs[2],cs[1]]!=0) { # this edge already exists
+			## do not allow to revert/revswitch if this edge already exists
+			if(bestmodel$phi[cs[2],cs[1]]!=0) {
 				poss <- poss[-p]
 			}
 		}
 		possback <- poss
+#		if(length(poss)>0) {			
+#			## check if edges would point to a stimulus node
+#			cds <- sapply(poss, coord, mat=bestmodel$phi)
+#			if(any(cds[1,] %in% unique(unlist(stimuli)))) {
+#				print("Error: revswitch edge would be drawn to a stimulus.")
+#				browser()
+#			}
+#		}
 	}
-	# pr that edge is chosen in the selected move: P(Edge|move)
-	pegm <- log(1/(length(poss)*nummoves)) / max(length(poss),1)
-	#pegm <- -log2(length(poss))
-	# pr that the move from above for the given edge is reverted: P(Edgechangeundo|move)
-	pegmundo <- log(1/((length(possback)+1) * nummoves))  / max(length(possback),1)
-	#pegmundo <- -log2((length(possback)+1))
-	if(length(poss)>0) {
+	if(length(poss)>0) {		
+		## pr that edge is chosen in the selected move: P(Edge|move)
+		pegm <- -log(length(poss)) - log(nummoves) ## v3
+		## pr that the move from above for the given edge is reverted: P(Edgechangeundo|move)
+		pegmundo <- -log(length(possback)) - log(nummoves) ## v3
+		## get the model variables
 		tps <- bestmodel$tps
 		stimuli <- bestmodel$stimuli
 		reps <- bestmodel$reps
@@ -84,18 +110,16 @@ mcmc_move <- function(bestmodel, type) {
 		it <- bestmodel$it
 		K <- bestmodel$K
 		priortype <- bestmodel$priortype
-		# permute poss to propose moves in different orders
-		#poss <- sample(poss)
 		counter <- 1
 		numbettermodel <- 1
 		bettermodels <- list()
 		
-		# select the move randomly
+		## select the move randomly
 		i <- ifelse(length(poss)>1,sample(poss, 1),poss[1])
 		phi.n <- bestmodel$phi
 		cds <- coord(i, phi.n)
-		if(cds[1]==cds[2]) {
-			print("ERROR: chosen element of the diagonal for the move.")
+		if(cds[1]==cds[2] || cds[2] %in% unique(unlist(stimuli))) {
+			print("ERROR: chosen element of the diagonal for the move or edge back to stimulus.")
 			browser()
 		}
 		switch(type,
@@ -104,10 +128,14 @@ mcmc_move <- function(bestmodel, type) {
 				addinhibition=phi.n[i] <- 2,
 				switchtype=phi.n[i] <- phi.n[i]%%2 + 1,
 				delete=phi.n[i] <- 0,
-				reverse=phi.n <- reverse.direction(phi.n,i))
+				reverse=phi.n <- reverse.direction(phi.n,i),
+				revswitch=phi.n <- reverse.direction(phi.n,i,switchtype=TRUE))
 		## debug me if constraints are violated
-		if(any(colSums(detailed.to.simple.regulations(phi.n))>fanin))
+		if(any(colSums(detailed.to.simple.regulations(phi.n))>fanin)) {
+			print("Oops, mcmc_move seems to produce more incoming edges that allowed according to fanin-setting.")
 			browser()
+		}
+		## HMM for the proposed network
 		L.res <- perform.hmmsearch(phi.n, bestmodel)	
 		gammaposs.n <- L.res$gammaposs
 		gamma.n <- matrix(L.res$gammax,nrow=nrow(bestmodel$gamma),ncol=ncol(bestmodel$gamma),dimnames=dimnames(bestmodel$gamma))
@@ -118,9 +146,8 @@ mcmc_move <- function(bestmodel, type) {
 		bic.n <- L.res$bic
 		aic.n <- L.res$aic
 		pr.n <- prior(phi.n, lambda, B, Z, gam, it, K, priortype)
-		if(priortype=="laplaceinhib" || priortype=="laplace" || priortype=="scalefree") {
+		if(priortype %in% c("laplaceinhib", "laplace", "scalefree")) {
 			posterior.n <- L.n + pr.n
-			#posterior.n <- posterior(phi.n, L.n, lambda, B, Z, gam, it, K)
 		} else {
 			posterior.n <- NULL			
 		}
@@ -134,7 +161,7 @@ mcmc_move <- function(bestmodel, type) {
 				#sd_thetax=bestmodel$sd_thetax)	
 		numbettermodel <- numbettermodel + 1
 	} else {
-		bettermodels <- list(bestmodel)
+		bettermodels <- NULL
 	}
 	return(bettermodels)
 }
